==> Xarm-1.2.7.tar.gz: Xarm-1.2.7/include/Xarm/ArrowBG.h <==
/* $Id: ArrowBG.h,v 1.3 1997/04/08 15:42:36 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_ARROWBG_H_)
#define _XARM_ARROWBG_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Gadget.h>

class ArrowButtonGadgetClass : public GadgetClass {
 protected:
   ArrowButtonGadgetClass() {}

   virtual WidgetClass classPointer() { return xmArrowButtonGadgetClass; }
   virtual _XtString className() { return (_XtString) "XmArrowButtonGadget"; }
 public:
   /* callbacks */
   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void armCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void disarmCallback(XtCallbackProc funcp, XtPointer data = NULL);

   /* resources */
   void arrowDirection(unsigned char);
   unsigned char arrowDirection();
   void multiClick(unsigned char);
   unsigned char multiClick();
};

class ArrowButtonGadget : public ArrowButtonGadgetClass {
 public:
   ArrowButtonGadget(Widget w_parent,
                     ArgList arglist = NULL, 
                     Cardinal argcnt = 0,
                     _XtString name = NULL);
   ArrowButtonGadget(_XtString name, Widget w_parent);
   ArrowButtonGadget(Widget w_parent, XarmArg &args, _XtString name);
};

#endif

==> Xarm-1.3.1.tar.gz: Xarm-1.3.1/include/Xarm/ArrowBG.h <==
/* $Id: ArrowBG.h,v 1.4 1999/01/14 03:35:18 glgay Exp $ */
/*
 Copyright (C) 1993, 1994 Jettero Heller
 Copyright (C) 1994, 1995 Peter Williams
 
 This library is free software; you can redistribute it and/or
 modify it under the terms of the GNU Library General Public License 
 version 2 as published by the Free Software Foundation.

 This library is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 Library General Public License for more details.

 You should have received a copy of the GNU Library General Public
 License along with this library; see the file COPYING.  If not,
 write to the Free Software Foundation, Inc., 675 Mass Ave, 
 Cambridge, MA 02139, USA.
*/


#if !defined(_XARM_ARROWBG_H_)
#define _XARM_ARROWBG_H_

/* ======================================================================= */
/* Include(s): */
#include <Xarm/Gadget.h>

class ArrowButtonGadgetClass : public GadgetClass {
 protected:
   ArrowButtonGadgetClass() {}

   virtual WidgetClass classPointer() { return xmArrowButtonGadgetClass; }
   virtual _XtString className() { return (_XtString) "XmArrowButtonGadget"; }
 public:
   /* callbacks */
   void activateCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void armCallback(XtCallbackProc funcp, XtPointer data = NULL);
   void disarmCallback(XtCallbackProc funcp, XtPointer data = NULL);

   /* resources */
   void arrowDirection(unsigned char);
   unsigned char arrowDirection() const;
   void multiClick(unsigned char);
   unsigned char multiClick() const;
};

class ArrowButtonGadget : public ArrowButtonGadgetClass {
 public:
   ArrowButtonGadget(Widget w_parent,
                     ArgList arglist = NULL, 
                     Cardinal argcnt = 0,
                     _XtString name = NULL);
   ArrowButtonGadget(_XtString name, Widget w_parent);
   ArrowButtonGadget(Widget w_parent, XarmArg &args, _XtString name);
};

#endif
